Getting Started with Schevo — libschevo 3.2.4 documentation

### Navigation

- index
- next |
- previous |
- libschevo 3.2.4 documentation »

# Getting Started with Schevo

Follow these steps to get a Schevo environment ready on your computer, ready for you to begin developing Schevo applications and following the tutorials.

You can use Schevo in whatever way you choose, but these pages describe the tools and techniques that Schevo documentation assumes you are using.

- Install Schevo on Microsoft Windows
  - Install Python
  - Install pywin32 extensions
  - Download Easy Install and virtualenv and set up an environment for Schevo
  - Activate the Schevo environment
  - Installing Schevo
  - What to do after Schevo is installed
  - Setting Environment Variables
- Install Schevo on Mac OS X
  - Notes on running Python
  - Install Python packages
  - Download workingenv and set up an environment for Schevo
  - Activate the Schevo environment
  - Installing Schevo
  - What to do after Schevo is installed

### Navigation

- index
- next |
- previous |
- libschevo 3.2.4 documentation »